# RESQML v2.0.1 objects

The module `resqml_objects.v201.generated` contains mostly auto-generated
[`xsdata`](https://xsdata.readthedocs.io/en/latest/)-dataclasses from the RESQML
v2.0.1 XSD Schema files found here:
[https://publications.opengroup.org/v231a](https://publications.opengroup.org/v231a).
We have added some default parameters, some `__post_init__`-methods, and a few
factory methods for setting up some common objects.
Most of the documentation is from the published XSD Schema files and is similar
to the documentation in the standards pdf.

::: resqml_objects.v201.generated
    options:
        show_if_no_docstring: false
